#!/bin/bash

# This script does the post install tasks specific for mingw32-*
# packages.

# If using normal root, avoid changing anything.
if [ -z "$RPM_BUILD_ROOT" -o "$RPM_BUILD_ROOT" = "/" ]; then
	exit 0
fi

LC_ALL=
LANG=
LC_TIME=POSIX

cd $RPM_BUILD_ROOT

[ -z "$STRIP" ] && STRIP=i686-w64-mingw32-strip

for f in `find . -type f -name "*.exe" -or -name "*.dll"`; do
	case $(i686-w64-mingw32-objdump -h $f 2>/dev/null | egrep -o '(debug[\.a-z_]*|gnu.version)') in
	    *debuglink*) continue ;;
	    *debug*) ;;
	    *gnu.version*)
		echo "WARNING: "`echo $f | sed -e "s,^$RPM_BUILD_ROOT/*,/,"`" is already stripped!"
		continue
		;;
	    *) continue ;;
	esac

    $STRIP --strip-unneeded $f;
done
for f in `find . -type f -name "*.a"`; do
	chmod -x $f;
done
for f in `find . -name "*.la"`; do
	rm -f $f;
done

if [ -d "$RPM_BUILD_ROOT/usr/i686-w64-mingw32/sys-root/mingw/share/man" ]; then
    pushd $RPM_BUILD_ROOT/usr/i686-w64-mingw32/sys-root/mingw/share/man
    for f in `find -type f`; do
	    case "$f" in
	        *.Z) gunzip $f; b=`echo $f | sed -e 's/\.Z$//'`;;
	        *.gz) gunzip $f; b=`echo $f | sed -e 's/\.gz$//'`;;
	        *.bz2) bunzip2 $f; b=`echo $f | sed -e 's/\.bz2$//'`;;
	        *) b=$f;;
	    esac
        gzip -9 -n $b
    done
	popd
fi
    

if [ -d "$RPM_BUILD_ROOT/usr/i686-w64-mingw32/sys-root/mingw/share/info" ]; then
    pushd $RPM_BUILD_ROOT/usr/i686-w64-mingw32/sys-root/mingw/share/info
    for f in `find -type f`; do
	    case "$f" in
	        *.Z) gunzip $f; b=`echo $f | sed -e 's/\.Z$//'`;;
	        *.gz) gunzip $f; b=`echo $f | sed -e 's/\.gz$//'`;;
	        *.bz2) bunzip2 $f; b=`echo $f | sed -e 's/\.bz2$//'`;;
	        *) b=$f;;
	    esac
        gzip -9 -n $b
    done
	popd
fi
    
if [ -d "$RPM_BUILD_ROOT/usr/i686-w64-mingw32/sys-root/mingw/lib/pkgconfig" ]; then
    pushd $RPM_BUILD_ROOT/usr/i686-w64-mingw32/sys-root/mingw/lib/pkgconfig
    for f in `find -name \*.pc`; do
        mv $f $f~
        sed \
         -e 's#L/usr/i686-w64-mingw32/sys-root/mingw/lib#L\${libdir}#g' \
         -e 's#I/usr/i686-w64-mingw32/sys-root/mingw/include#I\${includedir}#g' \
         -e 's#/usr/i686-w64-mingw32/sys-root/mingw#\${prefix}#g' \
         -e 's#^prefix=\${prefix}#prefix=/usr/i686-w64-mingw32/sys-root/mingw#g' \
         < $f~ > $f;
        rm -f $f~
    done
    popd
fi
    
if [ -d "$RPM_BUILD_ROOT/usr/i686-w64-mingw32/sys-root/mingw/share/pkgconfig" ]; then
    pushd $RPM_BUILD_ROOT/usr/i686-w64-mingw32/sys-root/mingw/share/pkgconfig
    for f in `find -name \*.pc`; do
        mv $f $f~
        sed \
         -e 's#L/usr/i686-w64-mingw32/sys-root/mingw/lib#L\${libdir}#g' \
         -e 's#I/usr/i686-w64-mingw32/sys-root/mingw/include#I\${includedir}#g' \
         -e 's#/usr/i686-w64-mingw32/sys-root/mingw#\${prefix}#g' \
         -e 's#^prefix=\${prefix}#prefix=/usr/i686-w64-mingw32/sys-root/mingw#g' \
         < $f~ > $f;
        rm -f $f~
    done
    popd
fi
    
